@@ -84,10 +84,6 @@
 
 @implementation OWResourceManager
 
-+ (int)version {
-  return 4;
-}
-
 static NSFileManager *fm                = nil;
 static Class    UrlClass                = Nil;
 static NSString *resourcePrefix         = @"";
@@ -383,7 +379,6 @@ _pathExists(OWResourceManager *self, NSFileManager *fm, NSString *path)
   */
   NSFileManager *fm;
   NSString      *resource = nil;
-  unsigned      langCount;
   
   if (debugResourceLookup) {
     [self logWithFormat:@"lookup '%@' bundle=%@ languages=%@", 
@@ -391,7 +386,6 @@ _pathExists(OWResourceManager *self, NSFileManager *fm, NSString *path)
   }
   
   fm        = [self fileManager];
-  langCount = [_languages count];
 
   /* now check in webserver resources path */
   
